@@ -71,29 +71,9 @@ int getSignedIntFromHex(const std::string &hex) {
     return rawVal;
 }
 
-int Bin2Dec(int n) {
-  // FROM: https://www.geeksforgeeks.org/program-binary-decimal-conversion/
-  int num = n;
-  int dec_value = 0;
-  // Initializing base value to 1, i.e 2^0
-  int base = 1;
-  int temp = num;
-  while (temp) {
-    int last_digit = temp % 10;
-    temp = temp / 10;
-    
-    dec_value += last_digit * base;
-    
-    base = base * 2;
-  }
-  return dec_value;
-}
-
 int getLight(const std::string &hex) {
   // input hex base is 16
   int rawVal = std::stoll(hex, nullptr, 16);
-  int lux;
-  lux = Bin2Dec(rawVal >> 2);
   return rawVal;
 }
 
@@ -132,7 +112,6 @@ Rcpp::List GENEActivReader(std::string filename, std::size_t start = 0, std::siz
         long blockTime = 0;  // Unix millis
         long lastvalue = 0;  // Unix millis
         double temperature = 0.0;
-        double volts = 0.0;
         double freq = 0.0;
         std::string data;
         std::string timeFmtStr = "Page Time:%Y-%m-%d %H:%M:%S:";
@@ -155,7 +134,6 @@ Rcpp::List GENEActivReader(std::string filename, std::size_t start = 0, std::siz
                     try {
                         std::getline(input_file, header);
                         if (i == 3) {
-                            std::tm tm = {};
                             std::stringstream ss(header);
                             int milliseconds;
                             ss >> milliseconds;
@@ -186,7 +164,6 @@ Rcpp::List GENEActivReader(std::string filename, std::size_t start = 0, std::siz
                 int yRaw = 0;
                 int zRaw = 0;
                 int lux = 0;
-                int last12 = 0;
                 double x = 0.0;
                 double y = 0.0;
                 double z = 0.0;
